@@ -9,21 +9,28 @@ struct Arguments {
     #[structopt(long, default_value = "127.0.0.1:8303")]
     address: String,
     #[structopt(long)]
-    password: String
+    password: String,
+    #[structopt(long)]
+    standard: bool
 }
 
 fn main() {
     let args = Arguments::from_args();
     let stdin = spawn_stdin_channel();
-    let conn = lib::EconConnection::connect(args.address.parse::<std::net::SocketAddr>().unwrap(), args.password);
+    let (cmd, msg) = lib::EconConnection::connect(args.address.parse::<std::net::SocketAddr>().unwrap(), args.password, String::from(":q!"));
     
     loop {
-        if let Ok(msg) = conn.recv() {
-            println!("{} : {} ::: {}", msg.get_timestamp(), msg.get_category(), msg.get_content());
+        if let Ok(msg) = msg.try_recv() {
+            if args.standard {
+                println!("{}", msg.to_string());
+            }
+            else {
+                println!("{} : {} ::: {}", msg.get_timestamp(), msg.get_category(), msg.get_content());
+            }
         }
 
         if let Ok(received) = stdin.try_recv() {
-            let _ = conn.send(received);
+            let _ = cmd.send(received);
         }
     }
 }
